PrefabFiles = {
	"ruby", "ruby_none", "crose", "rubycape", "bullet", "bullet_projectile",
}

Assets = {
    Asset( "IMAGE", "images/saveslot_portraits/ruby.tex" ),
    Asset( "ATLAS", "images/saveslot_portraits/ruby.xml" ),

    Asset( "IMAGE", "images/selectscreen_portraits/ruby.tex" ),
    Asset( "ATLAS", "images/selectscreen_portraits/ruby.xml" ),
	
    Asset( "IMAGE", "images/selectscreen_portraits/ruby_silho.tex" ),
    Asset( "ATLAS", "images/selectscreen_portraits/ruby_silho.xml" ),

    Asset( "IMAGE", "bigportraits/ruby.tex" ),
    Asset( "ATLAS", "bigportraits/ruby.xml" ),
	
	Asset( "IMAGE", "images/map_icons/ruby.tex" ),
	Asset( "ATLAS", "images/map_icons/ruby.xml" ),
	
	Asset( "IMAGE", "images/avatars/avatar_ruby.tex" ),
    Asset( "ATLAS", "images/avatars/avatar_ruby.xml" ),
	
	Asset( "IMAGE", "images/avatars/avatar_ghost_ruby.tex" ),
    Asset( "ATLAS", "images/avatars/avatar_ghost_ruby.xml" ),
	
	Asset( "IMAGE", "images/avatars/self_inspect_ruby.tex" ),
    Asset( "ATLAS", "images/avatars/self_inspect_ruby.xml" ),
	
	Asset( "IMAGE", "images/names_ruby.tex" ),
    Asset( "ATLAS", "images/names_ruby.xml" ),
	
    Asset( "IMAGE", "bigportraits/ruby_none.tex" ),
    Asset( "ATLAS", "bigportraits/ruby_none.xml" ),
	
	Asset( "ATLAS", "images/hud/rubytab.xml" ),	
}

local require = GLOBAL.require
local STRINGS = GLOBAL.STRINGS
local SpawnPrefab = GLOBAL.SpawnPrefab

local resolvefilepath = GLOBAL.resolvefilepath

local Ingredient = GLOBAL.Ingredient
local RECIPETABS = GLOBAL.RECIPETABS
local Recipe = GLOBAL.Recipe
local TECH = GLOBAL.TECH

GLOBAL.TUNING.ruby = {}
GLOBAL.TUNING.ruby.KEYTWO = GetModConfigData("key2") or 122

AddPlayerPostInit(function(inst)
   if inst.components.combat == nil then
        return
    end
	if GLOBAL.TheWorld.ismastersim then
		local old_start = inst.components.combat.StartAttack
		inst.components.combat.StartAttack = function(self)
			old_start(self)
			if self.target then
				local weapon = self:GetWeapon()
				if weapon and weapon.components.weapon and weapon.components.weapon.rosing and inst:HasTag("ruby") then
					local distance = math.sqrt(self.inst:GetDistanceSqToInst(self.target))
					local hitrange = weapon.components.weapon.hitrange
					if distance > hitrange then
						local smoke1 = SpawnPrefab("red_leaves")
						local smoke2 = SpawnPrefab("red_leaves")
						local sx, sy, sz = self.inst.Transform:GetWorldPosition()
						smoke1.Transform:SetPosition(sx, sy, sz)
						local fx, fy, fz = self.target.Transform:GetWorldPosition()
						local q = (distance - hitrange + 0.2) / distance
						local dx = sx - q * (sx - fx)
						local dy = sy - q * (sy - fy)
						local dz = sz - q * (sz - fz)
						inst.Transform:SetPosition(dx, dy, dz)
						smoke2.Transform:SetPosition(dx, dy, dz)
						inst.components.combat:SetAreaDamage(4, 0.5)
					end
				else
					inst.components.combat:SetAreaDamage(1, 0.75)
				end
			end
		end
	end
end)


GLOBAL.STRINGS.NAMES.CROSE = "Crescent Rose"
STRINGS.CHARACTERS.GENERIC.DESCRIBE.CROSE = "A scythe that is also a customizable, high impact sniper rifle."

GLOBAL.STRINGS.NAMES.RUBYCAPE = "Ruby's Cape"
STRINGS.CHARACTERS.GENERIC.DESCRIBE.RUBYCAPE = "Red like roses."

GLOBAL.STRINGS.NAMES.BULLET = "Sniper Ammo"
STRINGS.RECIPE_DESC.BULLET = "Ammo for your sweetheart." 
STRINGS.CHARACTERS.GENERIC.DESCRIBE.BULLET = "You can't shoot a gun without ammo, right?"

rubytab = AddRecipeTab("Ruby", 998, "images/hud/rubytab.xml", "rubytab.tex", "ruby_builder")

local bullet_recipe = AddRecipe("bullet",
{GLOBAL.Ingredient("gunpowder", 1), GLOBAL.Ingredient("goldnugget", 1), GLOBAL.Ingredient("flint", 5)},
rubytab, TECH.NONE,
nil, nil, nil, 5, nil,
"images/inventoryimages/bullet.xml", "bullet.tex")
bullet_recipe.tagneeded = false
bullet_recipe.builder_tag = "ruby_builder"
bullet_recipe.atlas = resolvefilepath("images/inventoryimages/bullet.xml")


-- The character select screen lines
STRINGS.CHARACTER_TITLES.ruby = "Red Rose"
STRINGS.CHARACTER_NAMES.ruby = "Ruby"
STRINGS.CHARACTER_DESCRIPTIONS.ruby = "*Fast\n*A bit childish\n*Scythe wielder"
STRINGS.CHARACTER_QUOTES.ruby = "\"I'm sure we can handle whatever gets thrown at us.\""

-- Custom speech strings	
STRINGS.CHARACTERS.ruby = require "speech_ruby"

-- The character's name as appears in-game 
STRINGS.NAMES.ruby = "Ruby"

-- The default responses of examining the character
STRINGS.CHARACTERS.GENERIC.DESCRIBE.ruby = 
{
	GENERIC = "It's Ruby!",
	ATTACKER = "That Ruby looks shifty...",
	MURDERER = "Murderer!",
	REVIVER = "Ruby, friend of ghosts.",
	GHOST = "Ruby could use a heart.",
}


AddMinimapAtlas("images/map_icons/ruby.xml")

-- Add mod character to mod character list. Also specify a gender. Possible genders are MALE, FEMALE, ROBOT, NEUTRAL, and PLURAL.
AddModCharacter("ruby", "FEMALE")

-- rspeed time[Z]
local function SpeedUp(inst)
	if inst:HasTag("playerghost") then return end
	if inst.transformed and inst.components.hunger.current>=5 and inst.components.sanity.current>=5 then
		inst.components.hunger.current = inst.components.hunger.current - 5
		inst.components.sanity:DoDelta(-5)
		inst.components.locomotor.walkspeed = 8.5
		inst.components.locomotor.runspeed = 12
		inst.components.sanity.night_drain_mult = 1.5
		inst.components.hunger:SetRate(TUNING.WILSON_HUNGER_RATE * 2.5)
		inst.components.combat:SetAttackPeriod(0.35)
		inst.components.health.absorb = (-0.15)
		SpawnPrefab("red_leaves").Transform:SetPosition(inst:GetPosition():Get())	
		inst.components.talker:Say("Just try and catch me now!", 1, true)	
	elseif inst.transformed and inst.components.hunger.current< 5 then
		inst.components.talker:Say("I'm too hungry", 1, true)
	elseif inst.transformed and inst.components.sanity.current< 5 then
		inst.components.talker:Say("I can't...", 1, true)
	else
		inst.components.locomotor.walkspeed = 4.6
		inst.components.locomotor.runspeed = 7
		inst.components.sanity.night_drain_mult = 0.75
		inst.components.hunger:SetRate(TUNING.WILSON_HUNGER_RATE)
		inst.components.combat:SetAttackPeriod(0.6)
		inst.components.health.absorb = 0
		SpawnPrefab("red_leaves").Transform:SetPosition(inst:GetPosition():Get())	
	end
	
inst.transformed = not inst.transformed

return true
	
end

AddModRPCHandler("ruby", "SpeedUp", SpeedUp)

-- Snipe action
local mysnipe = AddAction("SNIPING", "Snipe", function(act)
	act.invobject.components.snipeattack:DoAttack(act.doer, act.target)
	act.invobject.components.container:ConsumeByName("bullet", 1)
	act.doer.components.sanity:DoDelta(-2)
	return true
end)
mysnipe.distance = 20

-- Snipe tossing action
AddStategraphActionHandler("wilson", GLOBAL.ActionHandler(mysnipe, "attack"))

-- Snipe action linked to equipped items with sniping component
AddComponentAction("EQUIPPED", "snipeattack", function(inst, doer, target, actions, right)
	if right and target.replica.health and not target:HasTag("player") then
		table.insert(actions, mysnipe)
	end
end)