
local MakePlayerCharacter = require "prefabs/player_common"


local assets = {
    Asset("SCRIPT", "scripts/prefabs/player_common.lua"),
}
local prefabs = {}

-- Custom starting items
local start_inv = {
	"crose",
	"rubycape",
	"bullet",
	"bullet",
	"bullet",
	"bullet",
	"bullet",
	"bullet",
	"bullet",
	"bullet",
	"bullet",
	"bullet",
}

-- When the character is revived from human
local function onbecamehuman(inst)
	-- Set speed when loading or reviving from ghost (optional)
	inst.components.locomotor.walkspeed = 4.6
	inst.components.locomotor.runspeed = 7
	inst.components.combat:SetAttackPeriod(0.6)
end

local function onbecameghost(inst)
	inst.components.locomotor.walkspeed = 4.6
	inst.components.locomotor.runspeed = 7
end

-- When loading or spawning the character
local function onload(inst)
    inst:ListenForEvent("ms_respawnedfromghost", onbecamehuman)
	inst.components.locomotor.walkspeed = 4.6
	inst.components.locomotor.runspeed = 7
	inst.components.combat:SetAttackPeriod(0.6)
	
    if not inst:HasTag("playerghost") then
        onbecamehuman(inst)
    end
end

-- This initializes for both the server and client. Tags can be added here.
local common_postinit = function(inst) 
	-- Minimap icon
	inst.MiniMapEntity:SetIcon( "ruby.tex" )
	inst:AddTag("ruby")
	inst:AddTag("ruby_builder")
	inst.transformed = true
	inst:AddComponent("keyhandler")
    inst.components.keyhandler:AddActionListener("ruby", TUNING.ruby.KEYTWO, "SpeedUp")
end
	
-- This initializes for the server only. Components are added here.
local master_postinit = function(inst)
	-- choose which sounds this character will play
	inst.soundsname = "willow"
	
	-- Uncomment if "wathgrithr"(Wigfrid) or "webber" voice is used
    --inst.talker_path_override = "dontstarve_DLC001/characters/"
	
	-- Stats	
	inst.components.health:SetMaxHealth(125)
	inst.components.hunger:SetMax(130)
	inst.components.sanity:SetMax(120)
	inst.components.health:StartRegen(1, 20)
	
	inst.components.sanity.night_drain_mult = 0.75
	inst.components.sanity.neg_aura_mult = 0.75
	
	-- Damage multiplier (optional)
    inst.components.combat.damagemultiplier = 0.6

	-- Hunger rate (optional)
	inst.components.hunger.hungerrate = 1 * TUNING.WILSON_HUNGER_RATE
	
	inst:ListenForEvent("equip", function()
        local equippedwep = inst.components.inventory:GetEquippedItem(EQUIPSLOTS.HANDS)
		if equippedwep ~= nil and equippedwep:HasTag("scythe") then
            inst.components.combat.damagemultiplier = 4
        else
            inst.components.combat.damagemultiplier = 0.6
        end
    end)
	
	inst:ListenForEvent("unequip", function()
        local unequippedwep = inst.components.inventory:GetEquippedItem(EQUIPSLOTS.HANDS)
		if unequippedwep ~= nil and unequippedwep:HasTag("scythe") then
            inst.components.combat.damagemultiplier = 4
        else
            inst.components.combat.damagemultiplier = 0.6
        end
    end)	
	
	inst.OnLoad = onload
    inst.OnNewSpawn = onload
end

return MakePlayerCharacter("ruby", prefabs, assets, common_postinit, master_postinit, start_inv)
